==> apache-doris-4.0.2-rc02-src.tar.gz: apache-doris-4.0.2-rc02-src/be/src/vec/exprs/vslot_ref.h <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

#pragma once
#include <string>

#include "common/object_pool.h"
#include "common/status.h"
#include "vec/exprs/vexpr.h"

namespace doris {
class SlotDescriptor;
class RowDescriptor;
class RuntimeState;
class TExprNode;

namespace vectorized {
class Block;
class VExprContext;

class VSlotRef MOCK_REMOVE(final) : public VExpr {
    ENABLE_FACTORY_CREATOR(VSlotRef);

public:
    VSlotRef(const TExprNode& node);
    VSlotRef(const SlotDescriptor* desc);
#ifdef BE_TEST
    VSlotRef() = default;
    void set_column_id(int column_id) { _column_id = column_id; }
    void set_slot_id(int slot_id) { _slot_id = slot_id; }
#endif
    Status prepare(RuntimeState* state, const RowDescriptor& desc, VExprContext* context) override;
    Status open(RuntimeState* state, VExprContext* context,
                FunctionContext::FunctionStateScope scope) override;
    Status execute(VExprContext* context, Block* block, int* result_column_id) const override;
    Status execute_column(VExprContext* context, const Block* block,
                          ColumnPtr& result_column) const override;
    DataTypePtr execute_type(const Block* block) const override;

    const std::string& expr_name() const override;
    std::string expr_label() override;
    std::string debug_string() const override;
    bool is_constant() const override { return false; }

    int column_id() const { return _column_id; }

    MOCK_FUNCTION int slot_id() const { return _slot_id; }

    bool equals(const VExpr& other) override;

    size_t estimate_memory(const size_t rows) override { return 0; }

    void collect_slot_column_ids(std::set<int>& column_ids) const override {
        column_ids.insert(_column_id);
    }

    MOCK_FUNCTION const std::string& column_name() const { return *_column_name; }

private:
    int _slot_id;
    int _column_id;
    const std::string* _column_name = nullptr;
    const std::string _column_label;
};
} // namespace vectorized
} // namespace doris

==> apache-doris-4.0.3-rc03-src.tar.gz: apache-doris-4.0.3-rc03-src/be/src/vec/exprs/vslot_ref.h <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

#pragma once
#include <string>

#include "common/object_pool.h"
#include "common/status.h"
#include "vec/exprs/vexpr.h"

namespace doris {
class SlotDescriptor;
class RowDescriptor;
class RuntimeState;
class TExprNode;

namespace vectorized {
class Block;
class VExprContext;

class VSlotRef MOCK_REMOVE(final) : public VExpr {
    ENABLE_FACTORY_CREATOR(VSlotRef);

public:
    VSlotRef(const TExprNode& node);
    VSlotRef(const SlotDescriptor* desc);
#ifdef BE_TEST
    VSlotRef() = default;
    void set_column_id(int column_id) { _column_id = column_id; }
    void set_slot_id(int slot_id) { _slot_id = slot_id; }
#endif
    Status prepare(RuntimeState* state, const RowDescriptor& desc, VExprContext* context) override;
    Status open(RuntimeState* state, VExprContext* context,
                FunctionContext::FunctionStateScope scope) override;
    Status execute(VExprContext* context, Block* block, int* result_column_id) const override;
    Status execute_column(VExprContext* context, const Block* block, size_t count,
                          ColumnPtr& result_column) const override;
    DataTypePtr execute_type(const Block* block) const override;

    const std::string& expr_name() const override;
    std::string expr_label() override;
    std::string debug_string() const override;
    bool is_constant() const override { return false; }

    int column_id() const { return _column_id; }

    MOCK_FUNCTION int slot_id() const { return _slot_id; }

    bool equals(const VExpr& other) override;

    size_t estimate_memory(const size_t rows) override { return 0; }

    void collect_slot_column_ids(std::set<int>& column_ids) const override {
        column_ids.insert(_column_id);
    }

    MOCK_FUNCTION const std::string& column_name() const { return *_column_name; }

private:
    int _slot_id;
    int _column_id;
    const std::string* _column_name = nullptr;
    const std::string _column_label;
};
} // namespace vectorized
} // namespace doris
